.. role:: hidden
    :class: hidden-section


Data Feeds
==========

.. currentmodule:: sconce.data_feeds


:hidden:`DataFeed`
~~~~~~~~~~~~~~~~~~

.. autoclass:: DataFeed
    :members:

:hidden:`ImageFeed`
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ImageFeed

:hidden:`SingleClassImageFeed`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: SingleClassImageFeed
    :members:
    :show-inheritance:
    :inherited-members:


:hidden:`MultiClassImageFeed`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: MultiClassImageFeed
    :members:
    :show-inheritance:
    :inherited-members:
